@@ -33,11 +33,11 @@ class NotifyByLogfile : public KNotificationPlugin
     Q_OBJECT
 
 public:
-    NotifyByLogfile(QObject *parent = 0);
+    explicit NotifyByLogfile(QObject *parent = nullptr);
     virtual ~NotifyByLogfile();
 
-    virtual QString optionName() { return QStringLiteral("Logfile"); }
-    virtual void notify(KNotification *notification, KNotifyConfig *config);
+    QString optionName() Q_DECL_OVERRIDE { return QStringLiteral("Logfile"); }
+    void notify(KNotification *notification, KNotifyConfig *config) Q_DECL_OVERRIDE;
 };
 
 #endif
